# bambot/templates/agent_readme.md.j2
# AI Agent Deployment

This directory contains the files required to deploy your AI agent as a Docker container.

## Files

- `{{ bot_file }}`: This is your AI agent's code.
- `Dockerfile`: This file defines the Docker image for your AI agent.
- `Procfile`: This file is required for deploying your AI agent to Heroku.
- `requirements.txt`: This file lists the Python dependencies required by your AI agent.

## Deployment

### Local Deployment

To run your AI agent locally, you can use the `bam` command-line interface: